@@ -128,8 +128,7 @@ static PyObject* DatabaseObject_create_collection(DatabaseObject* self, PyObject
     return NULL;
   }
 
-  const char* content;
-  PyUnicode_AsUTF8String(name);
+  const char* content = PyUnicode_AsUTF8(name);
 
   int ec = 0;
   uint32_t col_id = 0;
